==> guikachu-0.7.tar.gz: guikachu-0.7/src/widgets/widget-combo.h <==
//$Id: widget-combo.h,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_WIDGETS_WIDGET_COMBO_H
#define GUIKACHU_WIDGETS_WIDGET_COMBO_H

namespace Guikachu
{
    namespace GUI
    {
	class WidgetCombo;
    }
}

#include <gtk--/box.h>
#include <gtk--/combo.h>
#include <gtk--/button.h>
#include "form-editor/widget.h"
#include "form-res.h"

namespace Guikachu
{
    namespace GUI
    {
	class WidgetCombo: public Gtk::HBox
	{
	    Resources::Form *form;
	    Gtk::Combo combo;
	    Gtk::Button button_edit;
	    
	    Widgets::Type type;
	    string current;
	    Widgets::Widget *current_widget;
	    
	    SigC::Slot0<string> get_val;
	    SigC::Slot1<void, string> set_val;
	public:
	    WidgetCombo (Resources::Form *form,
			 Widgets::Type type,
			 SigC::Slot0<string> get_slot,
			 SigC::Slot1<void, const string&> set_slot,
			 SigC::Signal0<void>& changed);
	private:
	    bool update_block;
	    void update ();
	    
	    void add_widget (Widgets::Widget *widget);
	    void remove_widget (Widgets::Widget *widget);
	    void widget_changed_cb (Widgets::Widget *widget);
	    void edit_cb ();
	    void entry_cb ();
	};
    }
}

#endif /* !GUIKACHU_WIDGET_COMBO_H */

==> guikachu-0.10.tar.gz: guikachu-0.10/src/widgets/widget-combo.h <==
//$Id: widget-combo.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_WIDGETS_WIDGET_COMBO_H
#define GUIKACHU_WIDGETS_WIDGET_COMBO_H

namespace Guikachu
{
    namespace GUI
    {
	class WidgetCombo;
    }
}

#include <gtk--/box.h>
#include <gtk--/combo.h>
#include <gtk--/button.h>
#include "property.h"
#include "form-editor/widget.h"
#include "form-res.h"

namespace Guikachu
{
    namespace GUI
    {
	class WidgetCombo: public Gtk::HBox
	{
	    Resources::Form *form;
	    Gtk::Combo combo;
	    Gtk::Button button_edit;
	    
	    Widgets::Type type;
	    string current;
	    Widgets::Widget *current_widget;

	    Property<string> &property;
	public:
	    WidgetCombo (Resources::Form  *form,
			 Widgets::Type     type,
			 Property<string> &property);
	private:
	    bool update_block;
	    void update ();
	    
	    void add_widget (Widgets::Widget *widget);
	    void remove_widget (Widgets::Widget *widget);
	    void widget_changed_cb (Widgets::Widget *widget);
	    void edit_cb ();
	    void entry_cb ();
	};
    }
}

#endif /* !GUIKACHU_WIDGET_COMBO_H */
